@@ -16,13 +16,10 @@
 
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file globus_ftp_client_restart_marker_plugin.c GridFTP Restart Marker Plugin Implementation
- *
- * $RCSfile: globus_ftp_client_restart_marker_plugin.c,v $
- * $Revision: 1.6 $
- * $Date: 2011/02/03 21:47:03 $
- * $Author: bester $
+ * @file globus_ftp_client_restart_marker_plugin.c
+ * @brief GridFTP Restart Marker Plugin Implementation
  */
+#endif
 
 #include "globus_ftp_client_restart_marker_plugin.h"
 #include <stdlib.h>
@@ -570,8 +567,6 @@ restart_marker_plugin_destroy_cb(
     globus_free(plugin);
 }
 
-#endif  /* GLOBUS_DONT_DOCUMENT_INTERNAL */
-
 /**
  * Initialize a restart marker plugin
  * @ingroup globus_ftp_client_restart_marker_plugin
